# Changelog

## 0.3.0 (2025-12-17)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** manual updates ([2140e69](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/2140e69f13a3c006ac49a2559a91ecbdb9b00d2c))
* **api:** manual updates ([b5b7fc5](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/b5b7fc5b38bc1e4a746a9188400610ae2b5cfb8c))
* **api:** update via SDK Studio ([3ed2cb5](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/3ed2cb52c561b78ee289c0c2bcd188523960be3e))


### Chores

* speedup initial import ([614310e](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/614310e06cacf5f3e7c235c31910f5941234abfc))
* update SDK settings ([4bdce59](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/4bdce59b742c975bb460e5cf4f8cbb733fbf3d7a))
* update SDK settings ([d62f93d](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/d62f93d446c70896dfc13b50de0db0c639bd2532))

## 0.2.0 (2025-12-16)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([2e66889](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/2e668897617ad90f8a18f90d309be827cc6b8f6c))
* **api:** manual updates ([70b6aeb](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/70b6aeb8802b5643b45a7739b012faded300a6d0))
* **api:** manual updates ([4826304](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/4826304533ae76a3760491f9116c20994b770664))


### Chores

* update SDK settings ([b8c06d9](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/b8c06d99b8bb55394e2c2b82494eac90ac9b1e08))
* update SDK settings ([8e3fa64](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/8e3fa64d663802a9bb0b095966c57851440967bb))

## 0.1.0 (2025-12-16)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([5975ea6](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/5975ea6b718ed085cda3bec2bf6f9fd9c045b7d5))


### Chores

* configure new SDK language ([9f9702d](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/9f9702d201e97fedeb35599b525d8b90ffce7235))
* sync repo ([0257455](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/0257455a755f2ea88538d613e5bfd90186601418))
* update SDK settings ([aead32f](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/aead32f5118497a4d9e95bcebf4f25d529f0277f))
* update SDK settings ([f9301f5](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/f9301f51e84fd282af9e7d2daebf5f4ea65ae94b))
* update SDK settings ([8624c03](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/8624c03a4ec295364788f219c68b97d62b8f15f4))
* update SDK settings ([547c2c0](https://github.com/Synext-Solution/cnos-hub-gen-sdk-py/commit/547c2c00cf59371ae084672636146a5032d58b81))
